Class: LibrariesIO::API
- Inherits:
-
TLAW::API
- Object
- TLAW::API
- LibrariesIO::API
- Defined in:
- lib/libraries_io/api.rb,
lib/libraries_io/aliases.rb
Constant Summary collapse
- PLATFORMS =
%i[go npm packagist maven rubygems pypi nuget bower wordpress cocoapods cpan cargo clojars cran meteor hackage atom hex puppet platformio homebrew emacs swiftpm pub carthage julia sublime dub elm racket haxelib nimble alcatraz purescript inqlude]
Class Method Summary collapse
Class Method Details
.setup_all_doc(prefix = nil, base = self) ⇒ Object
11 12 13 14 15 16 17 18 |
# File 'lib/libraries_io/doc.rb', line 11 def setup_all_doc(prefix = nil, base = self) base.endpoints.values.each do |endpoint| endpoint.docs_link ||= endpoint_doc(prefix, endpoint.symbol) end base.namespaces.values.each do |namespace| setup_all_doc(namespace.symbol, namespace) end end |